# AnisoCADO
[![Build Status](https://travis-ci.org/astronomyk/AnisoCADO.svg?branch=master)](https://travis-ci.org/astronomyk/AnisoCADO)
[![Documentation Status](https://readthedocs.org/projects/anisocado/badge/?version=latest)](https://anisocado.readthedocs.io/en/latest/?badge=latest)

A python package to generate off-axis PSFs for the SCAO mode for MICADO at the ELT

Please note: this package is not yet finished yet! The code is fine, but the 
documentation is severly lacking.

Apropos documentation. It can be found here:
[https://anisocado.readthedocs.io/en/latest/index.html](https://anisocado.readthedocs.io/en/latest/index.html)